==> haskell-gtk-sni-tray-0.1.8.1-349-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gtk-sni-tray.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   gtk-sni-tray
version:                0.1.8.1
visibility:             public
id:                     gtk-sni-tray-0.1.8.1-LX2TYa49IpK3BcKewyBYsJ
key:                    gtk-sni-tray-0.1.8.1-LX2TYa49IpK3BcKewyBYsJ
license:                BSD-3-Clause
copyright:              2018 Ivan Malison
maintainer:             IvanMalison@gmail.com
author:                 Ivan Malison
homepage:               https://github.com/IvanMalison/gtk-sni-tray#readme
synopsis:               A standalone StatusNotifierItem/AppIndicator tray
description:
    Please see the README on Github at <https://github.com/IvanMalison/gtk-sni-tray#readme>

category:               System
abi:                    3e39463a27d56cde441844565db98e4a
exposed:                True
exposed-modules:        StatusNotifier.TransparentWindow StatusNotifier.Tray
hidden-modules:         Paths_gtk_sni_tray
import-dirs:            /usr/lib/ghc-9.4.8/site-local/gtk-sni-tray-0.1.8.1
library-dirs:           /usr/lib/ghc-9.4.8/site-local/gtk-sni-tray-0.1.8.1
library-dirs-static:    /usr/lib/ghc-9.4.8/site-local/gtk-sni-tray-0.1.8.1
dynamic-library-dirs:   /usr/lib
data-dir:               /usr/share/haskell-gtk-sni-tray
hs-libraries:           HSgtk-sni-tray-0.1.8.1-LX2TYa49IpK3BcKewyBYsJ
extra-libraries:
    gtk-3 gdk-3 z pangocairo-1.0 cairo-gobject gdk_pixbuf-2.0 atk-1.0
    pango-1.0 cairo harfbuzz gio-2.0 gobject-2.0 glib-2.0

extra-libraries-static:
    gtk-3 gdk-3 z pangocairo-1.0 m Xrandr Xcursor Xcomposite Xdamage
    Xinerama cloudproviders cairo-gobject m dl gdk_pixbuf-2.0 m tiff
    jbig m deflate jpeg lzma pthread zstd webp m sharpyuv
    atk-bridge-2.0 atspi Xtst Xi Xfixes atk-1.0 dbus-1 systemd
    xkbcommon wayland-cursor wayland-egl wayland-client m rt epoxy dl
    GL EGL pangoft2-1.0 m pango-1.0 m fribidi thai datrie Xft cairo m
    dl fontconfig m expat m Xext Xrender X11 pthread xcb-render xcb-shm
    xcb Xau Xdmcp pixman-1 m harfbuzz-gobject harfbuzz m freetype dl
    bz2 png16 m m brotlidec brotlicommon graphite2 gio-2.0 gobject-2.0
    ffi gmodule-2.0 glib-2.0 m pcre2-8 z mount blkid sysprof-capture-4

include-dirs:
    /usr/include/gtk-3.0 /usr/include/pango-1.0
    /usr/include/cloudproviders /usr/include/cairo
    /usr/include/gdk-pixbuf-2.0 /usr/include/webp
    /usr/include/at-spi2-atk/2.0 /usr/include/at-spi-2.0
    /usr/include/atk-1.0 /usr/include/dbus-1.0
    /usr/lib/dbus-1.0/include /usr/include/fribidi
    /usr/include/pixman-1 /usr/include/harfbuzz /usr/include/freetype2
    /usr/include/libpng16 /usr/include/gio-unix-2.0
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/libmount /usr/include/blkid /usr/include/sysprof-6

depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    dbus-1.3.3-89HX9WsE6s87w80Su2vjXE directory-1.3.7.1
    enclosed-exceptions-1.0.3-5d5HkG9f42L9gkAITIDDVK filepath-1.4.2.2
    gi-cairo-1.0.29-IZ0kZ3DT9RsL7wr0wwwEhG
    gi-cairo-connector-0.1.1-5usuUzqtXCS6xOSj1akzFP
    gi-cairo-render-0.1.2-41jsVKJ3dg736mUs7hOL83
    gi-dbusmenugtk3-0.4.15-6JEGxmG02JX2yvgl2fvXKS
    gi-gdk-3.0.28-FCL5V5q2onC1uJaFHznbAb
    gi-gdkpixbuf-2.0.32-FA2p8fq62qlGYtinLsrkeN
    gi-glib-2.0.30-60JxzK0P7za1Bnj59m4FoX
    gi-gtk-3.0.41-1meioaTozEPFRD2paNCXU7
    gtk-strut-0.1.3.2-JIm6W2nor4WGcPHh64OhY6
    haskell-gi-0.26.14-I80ZxQcfVsk9fbxknQp0lw
    haskell-gi-base-0.26.7-IKgSSFp3EiO52VN49Ye8zT
    hslogger-1.3.2.0-2VvIfXniGBBG1Z464pLxt3
    status-notifier-item-0.3.1.0-94B74iDPAyREeId5KP9LkE text-2.0.2
    transformers-0.5.6.2 transformers-base-0.4.6-GqnHbqWDT0e8qlqX7fWzwX
    unix-2.7.3

haddock-interfaces:
    /usr/share/doc/haskell-gtk-sni-tray/html/gtk-sni-tray.haddock

haddock-html:           /usr/share/doc/haskell-gtk-sni-tray/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gtk-sni-tray-0.1.8.1-350-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gtk-sni-tray.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   gtk-sni-tray
version:                0.1.8.1
visibility:             public
id:                     gtk-sni-tray-0.1.8.1-7WyOVCKFedV2t7Isai21kE
key:                    gtk-sni-tray-0.1.8.1-7WyOVCKFedV2t7Isai21kE
license:                BSD-3-Clause
copyright:              2018 Ivan Malison
maintainer:             IvanMalison@gmail.com
author:                 Ivan Malison
homepage:               https://github.com/IvanMalison/gtk-sni-tray#readme
synopsis:               A standalone StatusNotifierItem/AppIndicator tray
description:
    Please see the README on Github at <https://github.com/IvanMalison/gtk-sni-tray#readme>

category:               System
abi:                    7e5da960a269dfb1c403139af1495e79
exposed:                True
exposed-modules:        StatusNotifier.TransparentWindow StatusNotifier.Tray
hidden-modules:         Paths_gtk_sni_tray
import-dirs:            /usr/lib/ghc-9.4.8/site-local/gtk-sni-tray-0.1.8.1
library-dirs:           /usr/lib/ghc-9.4.8/site-local/gtk-sni-tray-0.1.8.1
library-dirs-static:    /usr/lib/ghc-9.4.8/site-local/gtk-sni-tray-0.1.8.1
dynamic-library-dirs:   /usr/lib
data-dir:               /usr/share/haskell-gtk-sni-tray
hs-libraries:           HSgtk-sni-tray-0.1.8.1-7WyOVCKFedV2t7Isai21kE
extra-libraries:
    gtk-3 gdk-3 z pangocairo-1.0 cairo-gobject gdk_pixbuf-2.0 atk-1.0
    pango-1.0 cairo harfbuzz gio-2.0 gobject-2.0 glib-2.0

extra-libraries-static:
    gtk-3 gdk-3 z pangocairo-1.0 m Xrandr Xcursor Xcomposite Xdamage
    Xinerama cloudproviders cairo-gobject m dl gdk_pixbuf-2.0 m tiff
    jbig m deflate jpeg lzma pthread zstd webp m sharpyuv
    atk-bridge-2.0 atspi Xtst Xi Xfixes atk-1.0 dbus-1 systemd
    xkbcommon wayland-cursor wayland-egl wayland-client m rt epoxy dl
    GL EGL pangoft2-1.0 m pango-1.0 m fribidi thai datrie Xft cairo m
    dl fontconfig m expat m Xext Xrender X11 pthread xcb-render xcb-shm
    xcb Xau Xdmcp pixman-1 m harfbuzz-gobject harfbuzz m freetype dl
    bz2 png16 m m brotlidec brotlicommon graphite2 gio-2.0 gobject-2.0
    ffi gmodule-2.0 glib-2.0 m pcre2-8 z mount blkid sysprof-capture-4

include-dirs:
    /usr/include/gtk-3.0 /usr/include/pango-1.0
    /usr/include/cloudproviders /usr/include/cairo
    /usr/include/gdk-pixbuf-2.0 /usr/include/webp
    /usr/include/at-spi2-atk/2.0 /usr/include/at-spi-2.0
    /usr/include/atk-1.0 /usr/include/dbus-1.0
    /usr/lib/dbus-1.0/include /usr/include/fribidi
    /usr/include/pixman-1 /usr/include/harfbuzz /usr/include/freetype2
    /usr/include/libpng16 /usr/include/gio-unix-2.0
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/libmount /usr/include/blkid /usr/include/sysprof-6

depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    dbus-1.3.3-89HX9WsE6s87w80Su2vjXE directory-1.3.7.1
    enclosed-exceptions-1.0.3-5d5HkG9f42L9gkAITIDDVK filepath-1.4.2.2
    gi-cairo-1.0.29-IZ0kZ3DT9RsL7wr0wwwEhG
    gi-cairo-connector-0.1.1-5usuUzqtXCS6xOSj1akzFP
    gi-cairo-render-0.1.2-41jsVKJ3dg736mUs7hOL83
    gi-dbusmenugtk3-0.4.15-6VQcd4VhyIPJpOAppY6636
    gi-gdk-3.0.28-D4SmGW4fNKebbQRtPmFnT
    gi-gdkpixbuf-2.0.32-FA2p8fq62qlGYtinLsrkeN
    gi-glib-2.0.30-60JxzK0P7za1Bnj59m4FoX
    gi-gtk-3.0.41-9OOvuqGT218xexAHSOHSK
    gtk-strut-0.1.3.2-K3vxmnZZEUFGo4tptXt7ME
    haskell-gi-0.26.14-I80ZxQcfVsk9fbxknQp0lw
    haskell-gi-base-0.26.7-IKgSSFp3EiO52VN49Ye8zT
    hslogger-1.3.2.0-2VvIfXniGBBG1Z464pLxt3
    status-notifier-item-0.3.1.0-94B74iDPAyREeId5KP9LkE text-2.0.2
    transformers-0.5.6.2 transformers-base-0.4.6-GqnHbqWDT0e8qlqX7fWzwX
    unix-2.7.3

haddock-interfaces:
    /usr/share/doc/haskell-gtk-sni-tray/html/gtk-sni-tray.haddock

haddock-html:           /usr/share/doc/haskell-gtk-sni-tray/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
